arm64: Clean up VarHandle intrinsics implementation.
Fix some typos and update some table lookup code that's
currently unused. Bring in a few things from arm (naming,
static assertion, pull an expression to a named variable).
Test: testrunner.py --target --64 --optimizing
Bug: 71781600
Change-Id: If2f2c4417942a272a8ad672c6b876e0569f8827c
diff --git a/compiler/optimizing/code_generator_arm64.h b/compiler/optimizing/code_generator_arm64.h
index ec48245..c7c11f5 100644
--- a/compiler/optimizing/code_generator_arm64.h
+++ b/compiler/optimizing/code_generator_arm64.h
@@ -808,9 +808,9 @@
uint32_t offset,
vixl::aarch64::Label* fixup_label,
ReadBarrierOption read_barrier_option);
- // Generate MOV for the `old_value` in UnsafeCASObject and mark it with Baker read barrier.
- void GenerateUnsafeCasOldValueMovWithBakerReadBarrier(vixl::aarch64::Register marked,
- vixl::aarch64::Register old_value);
+ // Generate MOV for the `old_value` in intrinsic CAS and mark it with Baker read barrier.
+ void GenerateIntrinsicCasMoveWithBakerReadBarrier(vixl::aarch64::Register marked_old_value,
+ vixl::aarch64::Register old_value);
// Fast path implementation of ReadBarrier::Barrier for a heap
// reference field load when Baker's read barriers are used.
// Overload suitable for Unsafe.getObject/-Volatile() intrinsic.